Learn R Programming

BayesCPclust (version 0.1.0)

pk: Probability mass function for truncated poisson

Description

Probability mass function for truncated poisson

Usage

pk(k, kstar, lambda)

Value

`pk` returns a numerical value representing the marginal probability for a given k

Arguments

k

A scalar for the number of changes points in a cluster

kstar

A scalar with the number maximum of change points in all clusters

lambda

A scalar defining the parameter for the Truncate Poisson distribution that controls the number of change points (or its initial values)

See Also

[gibbs_alg()]

Examples

Run this code
# Hypothetical values
pk(k = 2, kstar = 3, lambda = 2)

Run the code above in your browser using DataLab