powered by
Full conditional for lambda
full_cond(kstar, lambda, cluster, al, bl, K, N)
`full_cond` returns a numerical value corresponding to a sample from the full conditional for lambda
A scalar with the number maximum of change points in all clusters
A scalar defining the parameter for the Truncate Poisson distribution that controls the number of change points (or its initial values)
A vector containing the cluster assignments for the data sequences (or its initial values)
The hyperparameter value for the shape parameter in the gamma prior for lambda
The hyperparameter value for the scale parameter in the gamma prior for lambda
A vector containing the number of change points for each cluster (or its initial values)
A scalar representing the number of data sequences
# Using hypothetical values to exemplification purposes clusters <- c(1,1,2,1,2) full_cond(kstar = 2, lambda = 3, cluster = clusters, al = 2, bl = 1000, K = c(2, 2), N = 5)
Run the code above in your browser using DataLab