powered by
Probability mass function for truncated poisson
pk(k, kstar, lambda)
`pk` returns a numerical value representing the marginal probability for a given k
A scalar for the number of changes points in a cluster
A scalar with the number maximum of change points in all clusters
A scalar defining the parameter for the Truncate Poisson distribution that controls the number of change points (or its initial values)
[gibbs_alg()]
# Hypothetical values pk(k = 2, kstar = 3, lambda = 2)
Run the code above in your browser using DataLab