powered by
Full conditional function for sigma2
possigma2n(as, bs, M, Yn, k, Tln, alphan)
A numerical value corresponding to a sampled value from the full conditional of the variance component
The hyperparameter value for the shape parameter in the inverse-gamma prior for the variance component
The hyperparameter value for the scale parameter in the inverse-gamma prior for the variance component
A scalar representing the number of points available for each data sequence
A vector or matrix with data sequences for a cluster
A scalar for the number of changes points in a cluster
A vector with the change-point positions for a cluster
A vector with the constant level values for each interval between change points for a cluster
[gibbs_alg()]
data(data) possigma2n(as = 2, bs = 1000, M = 50, Yn = data[,1], k = 0, Tln = 50, alphan = 15)
Run the code above in your browser using DataLab