powered by
Mixing probability for creating new cluster
qn0(alpha0, w, N, M, bs, as, kstar, lambda, Yn)
A numerical value representing the mixing value term used to compute the probability that the given data sequence should be a singleton cluster
A scalar defining the parameter for the Dirichlet process prior that controls the number of clusters (or its initial values)
A scalar representing the minimum number of points in each interval between two change points
A scalar representing the number of data sequences
A scalar representing the number of points available for each data sequence
The hyperparameter value for the scale parameter in the inverse-gamma prior for the variance component
The hyperparameter value for the shape parameter in the inverse-gamma prior for the variance component
A scalar with the number maximum of change points in all clusters
A scalar defining the parameter for the Truncate Poisson distribution that controls the number of change points (or its initial values)
A vector or matrix with data sequences for a cluster
[gibbs_alg()]
qn0(alpha0 = 1/100, w = 10, N = 5, M = 50, bs = 1000, as = 2, kstar = 2, lambda = 2, Yn = data[,1])
Run the code above in your browser using DataLab